@@ -27,11 +27,7 @@
 
 #include <qstring.h>
 #include <qstringlist.h>
-#include <q3ptrlist.h>
 #include <qmap.h>
-#include <q3ptrvector.h>
-#include <qcolor.h>
-
 
 #include "costitem.h"
 #include "subcost.h"
@@ -165,30 +161,32 @@ class TraceFile;
 class TracePart;
 class TraceData;
 
-typedef Q3PtrList<ProfileCostArray> TraceCostList;
-typedef Q3PtrList<TraceJumpCost> TraceJumpCostList;
-typedef Q3PtrList<TraceCallCost> TraceCallCostList;
-typedef Q3PtrList<TraceInclusiveCost> TraceInclusiveCostList;
+typedef QList<ProfileCostArray*> TraceCostList;
+typedef QList<TraceJumpCost*> TraceJumpCostList;
+typedef QList<TraceCallCost*> TraceCallCostList;
+typedef QList<TraceInclusiveCost*> TraceInclusiveCostList;
 
-typedef Q3PtrList<TracePartCall>  TracePartCallList;
-typedef Q3PtrList<TracePartInstr> TracePartInstrList;
-typedef Q3PtrList<TracePartLine>  TracePartLineList;
-typedef Q3PtrList<TracePartLineRegion>  TracePartLineRegionList;
-typedef Q3PtrList<TracePartFunction>  TracePartFunctionList;
-typedef Q3PtrList<TracePartInstrCall> TracePartInstrCallList;
-typedef Q3PtrList<TracePartLineCall>  TracePartLineCallList;
+typedef QList<TracePartCall*> TracePartCallList;
+typedef QList<TracePartInstr*> TracePartInstrList;
+typedef QList<TracePartLine*> TracePartLineList;
+typedef QList<TracePartLineRegion*> TracePartLineRegionList;
+typedef QList<TracePartFunction*> TracePartFunctionList;
+typedef QList<TracePartInstrCall*> TracePartInstrCallList;
+typedef QList<TracePartLineCall*> TracePartLineCallList;
+typedef QList<TracePart*> TracePartList;
 
-
-typedef Q3PtrList<TraceInstr> TraceInstrList;
-typedef Q3PtrList<TraceLine> TraceLineList;
-typedef Q3PtrList<TraceInstrCall> TraceInstrCallList;
-typedef Q3PtrList<TraceLineCall> TraceLineCallList;
-typedef Q3PtrList<TraceCall> TraceCallList;
-typedef Q3PtrList<TraceFile> TraceFileList;
-typedef Q3PtrList<TraceLineRegion> TraceLineRegionList;
-typedef Q3PtrList<TraceFunctionSource> TraceFunctionSourceList;
-typedef Q3PtrList<TraceFunction> TraceFunctionList;
-typedef Q3PtrList<TraceFunctionCycle> TraceFunctionCycleList;
+typedef QList<TraceInstr*> TraceInstrList;
+typedef QList<TraceLine*> TraceLineList;
+typedef QList<TraceInstrJump*> TraceInstrJumpList;
+typedef QList<TraceLineJump*> TraceLineJumpList;
+typedef QList<TraceInstrCall*> TraceInstrCallList;
+typedef QList<TraceLineCall*> TraceLineCallList;
+typedef QList<TraceCall*> TraceCallList;
+typedef QList<TraceFile*> TraceFileList;
+typedef QList<TraceLineRegion*> TraceLineRegionList;
+typedef QList<TraceFunctionSource*> TraceFunctionSourceList;
+typedef QList<TraceFunction*> TraceFunctionList;
+typedef QList<TraceFunctionCycle*> TraceFunctionCycleList;
 typedef QMap<QString, TraceObject> TraceObjectMap;
 typedef QMap<QString, TraceClass> TraceClassMap;
 typedef QMap<QString, TraceFile> TraceFileMap;
@@ -657,7 +655,7 @@ public:
 class TracePart: public TraceListCost
 {
 public:
-  TracePart(TraceData*, QFile* file);
+  TracePart(TraceData*);
   virtual ~TracePart();
 
   virtual TracePart* part() { return this; }
@@ -665,19 +663,20 @@ public:
 
   QString shortName() const;
   QString prettyName() const;
-  QFile* file() const { return _file; }
+  /// @return Name of the file this part was loaded from
   QString name() const { return _name; }
   QString description() const { return _descr; }
   QString trigger() const { return _trigger; }
   QString timeframe() const { return _timeframe; }
   QString version() const { return _version; }
-  int partNumber() { return _number; }
-  int threadID() { return _tid; }
-  int processID() { return _pid; }
+  int partNumber() const { return _number; }
+  int threadID() const { return _tid; }
+  int processID() const { return _pid; }
   void setDescription(const QString& d) { _descr = d; }
   void setTrigger(const QString& t) { _trigger = t; }
   void setTimeframe(const QString& t) { _timeframe = t; }
   void setVersion(const QString& v) { _version = v; }
+  void setName(const QString& n) { _name = n; }
   void setPartNumber(int n);
   void setThreadID(int t);
   void setProcessID(int p);
@@ -688,10 +687,13 @@ public:
 
   // returns true if something changed
   bool activate(bool);
-  bool isActive() { return _active; }
+  bool isActive() const { return _active; }
+
+  // for sorting
+  bool operator<(const TracePart&) const;
 
 private:
-  QFile* _file;
+  QIODevice* _file;
   QString _name;
   QString _descr;
   QString _trigger;
@@ -710,14 +712,6 @@ private:
 };
 
 
-class TracePartList: public Q3PtrList<TracePart>
-{
- public:
-  QString names() const;
- protected:
-  int compareItems ( Item item1, Item item2 );
-};
-
 
 /*-----------------------------------------------------------------
  * Classes for cost items summed up from multiple trace parts
@@ -753,19 +747,6 @@ public:
     TracePartInstrJump* _first;
 };
 
-class TraceInstrJumpList: public Q3PtrList<TraceInstrJump>
-{
- public:
-    TraceInstrJumpList() { _sortLow = true; }
-    void setSortLow(bool s) { _sortLow = s; }
-
- protected:
-  int compareItems ( Item item1, Item item2 );
-
- private:
-  bool _sortLow;
-};
-
 
 /**
  * A jump from one line to another inside of a function.
@@ -795,20 +776,6 @@ class TraceLineJump: public TraceJumpListCost
 };
 
 
-class TraceLineJumpList: public Q3PtrList<TraceLineJump>
-{
- public:
-    TraceLineJumpList() { _sortLow = true; }
-    void setSortLow(bool s) { _sortLow = s; }
-
- protected:
-  int compareItems ( Item item1, Item item2 );
-
- private:
-  bool _sortLow;
-};
-
-
 /**
  * A call from an instruction of one function to another function
  */
@@ -1143,7 +1110,7 @@ class TraceAssoziation
   bool _valid;
 };
 
-typedef Q3PtrList<TraceAssoziation> TraceAssoziationList;
+typedef QList<TraceAssoziation*> TraceAssoziationList;
 
 /**
  * A traced function
@@ -1184,6 +1151,7 @@ class TraceFunction: public TraceCostItem
   QString location(int maxFiles = 0) const;
 
   QString prettyName() const;
+  QString formattedName() const;
   static QString prettyEmptyName();
   QString prettyLocation(int maxFiles = 0) const;
   QString prettyNameWithLocation(int maxFiles = 1) const;
@@ -1397,6 +1365,7 @@ class TraceData: public ProfileCostArray
  public:
   TraceData(Logger* l = 0);
   TraceData(const QString& base);
+  TraceData(QIODevice* file, const QString& filename);
   virtual ~TraceData();
 
   virtual TraceData* data() { return this; }
@@ -1409,6 +1378,7 @@ class TraceData: public ProfileCostArray
    * Returns the number of parts loaded
    */
   int load(const QString&);
+  int load(QIODevice*, const QString&);
 
   /** returns true if something changed. These do NOT
    * invalidate the dynamic costs on a activation change,
@@ -1421,6 +1391,9 @@ class TraceData: public ProfileCostArray
   bool activatePart(TracePart*, bool active);
   bool activateAll(bool active=true);
 
+  // to be used by loader
+  void addPart(TracePart*);
+
   TracePartList parts() const { return _parts; }
   TracePart* partWithName(const QString& name);
 
@@ -1496,8 +1469,8 @@ class TraceData: public ProfileCostArray
 
  private:
   void init();
-  // add trace part: events from one trace file
-  TracePart* addPart(const QString& dir, const QString& file);
+  // add profile parts from one file
+  int internalLoad(QIODevice* file, const QString& filename);
 
   // for notification callbacks
   Logger* _logger;
