@@ -51,6 +51,7 @@ class OKTETAKASTENCONTROLLERS_EXPORT StructTool : public AbstractTool
 {
 Q_OBJECT
     Q_DISABLE_COPY(StructTool)
+
 public:
     StructTool();
     virtual ~StructTool();
@@ -110,6 +111,9 @@ protected Q_SLOTS:
     void onContentsChange(const Okteta::ArrayChangeMetricsList&);
     void onChildItemDataChanged();
 
+private:
+    Okteta::Address startAddress(const DataInformation* data);
+
 protected:
     QScopedPointer<StructToolPrivate> d;
 };
