@@ -1,20 +1,20 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2008                                                *
- *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
+ *   copyright (C) 2002-2009                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef CMD_CHANGELINECOLOR_H
 #define CMD_CHANGELINECOLOR_H
 
 #include <QtGui/QUndoCommand>
+#include <QtGui/QColor>
 
-#include "umlwidget.h"
+class UMLWidget;
 
 namespace Uml
 {
@@ -27,16 +27,13 @@ namespace Uml
         void redo();
         void undo();
 
-            private:
+    private:
+        UMLWidget* m_umlWidget;
+        //UMLView* m_view;
 
-                UMLWidget *UMLw;
-                //MLView *pView;
-
-                /* ancienne couleur */
-                QColor oldColor;
-
-                /* nouvelle couleur */
-                QColor color;
+        QColor m_oldColor;
+        QColor m_newColor;
     };
 }
-#endif /*CMD_CHANGELINECOLOR_H*/
+
+#endif // CMD_CHANGELINECOLOR_H
