@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2011                                               *
+ *   copyright (C) 2004-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -31,12 +31,13 @@
  * @param umlScene The UMLScene to use.
  */
 ToolBarStateMessages::ToolBarStateMessages(UMLScene *umlScene)
-  : ToolBarStatePool(umlScene)
+  : ToolBarStatePool(umlScene),
+    m_firstObject(0),
+    m_messageLine(0),
+    m_isObjectWidgetLine(false),
+    xclick(0),
+    yclick(0)
 {
-    m_firstObject = 0;
-    m_messageLine = 0;
-    xclick = 0;
-    yclick = 0;
 }
 
 /**
@@ -109,18 +110,19 @@ void ToolBarStateMessages::setCurrentElement()
 {
     m_isObjectWidgetLine = false;
 
-    ObjectWidget* objectWidgetLine = m_pUMLScene->onWidgetLine(m_pMouseEvent->pos());
+    ObjectWidget* objectWidgetLine = m_pUMLScene->onWidgetLine(m_pMouseEvent->scenePos());
     if (objectWidgetLine) {
+        uDebug() << Q_FUNC_INFO << "Object detected";
         setCurrentWidget(objectWidgetLine);
         m_isObjectWidgetLine = true;
         return;
     }
-
+    uDebug() << Q_FUNC_INFO << "Object NOT detected";
     //commit 515177 fixed a setting creation messages only working properly at 100% zoom
     //However, the applied patch doesn't seem to be necessary no more, so it was removed
     //The widgets weren't got from UMLView, but from a method in this class similarto the
     //one in UMLView but containing special code to handle the zoom
-    UMLWidget *widget = m_pUMLScene->widgetAt(m_pMouseEvent->pos());
+    UMLWidget *widget = m_pUMLScene->widgetAt(m_pMouseEvent->scenePos());
     if (widget) {
         setCurrentWidget(widget);
         return;
@@ -143,7 +145,7 @@ void ToolBarStateMessages::mouseReleaseWidget()
     //TODO When an association between UMLObjects of invalid types is made, an error message
     //is shown. Shouldn't also a message be used here?
     if (m_pMouseEvent->button() != Qt::LeftButton ||
-                getCurrentWidget()->baseType() != WidgetBase::wt_Object) {
+                currentWidget()->baseType() != WidgetBase::wt_Object) {
         cleanMessage();
         return;
     }
@@ -153,14 +155,14 @@ void ToolBarStateMessages::mouseReleaseWidget()
     }
 
     if (!m_isObjectWidgetLine) {
-        setSecondWidget(static_cast<ObjectWidget*>(getCurrentWidget()), CreationMessage);
+        setSecondWidget(static_cast<ObjectWidget*>(currentWidget()), CreationMessage);
         return;
     }
 
     if (!m_firstObject) {
-        setFirstWidget(static_cast<ObjectWidget*>(getCurrentWidget()));
+        setFirstWidget(static_cast<ObjectWidget*>(currentWidget()));
     } else {
-        setSecondWidget(static_cast<ObjectWidget*>(getCurrentWidget()), NormalMessage);
+        setSecondWidget(static_cast<ObjectWidget*>(currentWidget()), NormalMessage);
     }
 }
 
@@ -174,37 +176,28 @@ void ToolBarStateMessages::mouseReleaseEmpty()
     Uml::Sequence_Message_Type msgType = getMessageType();
 
     if (m_firstObject && msgType ==  Uml::sequence_message_lost) {
-        xclick = m_pMouseEvent->x();
-        yclick = m_pMouseEvent->y();
-
-        MessageWidget* message = new MessageWidget(m_pUMLScene, m_firstObject,xclick, yclick, msgType);
+        xclick = m_pMouseEvent->scenePos().x();
+        yclick = m_pMouseEvent->scenePos().y();
 
+        MessageWidget* message = new MessageWidget(m_pUMLScene, m_firstObject, xclick, yclick, msgType);
+        setupMessageWidget(message);
         cleanMessage();
-        m_pUMLScene->getMessageList().append(message);
         xclick = 0;
         yclick = 0;
-
-        FloatingTextWidget *ft = message->floatingTextWidget();
-        //TODO cancel doesn't cancel the creation of the message, only cancels setting an operation.
-        //Shouldn't it cancel also the whole creation?
-        ft->showOperationDialog();
-        message->setTextPosition();
-        m_pUMLScene->getWidgetList().append(ft);
-
-        UMLApp::app()->document()->setModified();
     }
 
     else if (!m_firstObject && msgType == Uml::sequence_message_found && xclick == 0 && yclick == 0) {
-        xclick = m_pMouseEvent->x();
-        yclick = m_pMouseEvent->y();
+        xclick = m_pMouseEvent->scenePos().x();
+        yclick = m_pMouseEvent->scenePos().y();
 
-        m_messageLine = new UMLSceneLineItem(m_pUMLScene->canvas());
+        m_messageLine = new UMLSceneLineItem();
+        m_messageLine->setCanvas(m_pUMLScene->canvas());
         m_messageLine->setPoints(m_pMouseEvent->x(), m_pMouseEvent->y(), m_pMouseEvent->x(), m_pMouseEvent->y());
         m_messageLine->setPen(QPen(m_pUMLScene->lineColor(), m_pUMLScene->lineWidth(), Qt::DashLine));
 
         m_messageLine->setVisible(true);
 
-        m_pUMLScene->viewport()->setMouseTracking(true);
+        m_pUMLScene->view()->viewport()->setMouseTracking(true);
     }
     else {
         cleanMessage();
@@ -225,29 +218,20 @@ void ToolBarStateMessages::setFirstWidget(ObjectWidget* firstObject)
 
     if (msgType ==  Uml::sequence_message_found && xclick!=0 && yclick!=0) {
         MessageWidget* message = new MessageWidget(m_pUMLScene, m_firstObject,xclick, yclick, msgType);
+        setupMessageWidget(message);
         cleanMessage();
-        m_pUMLScene->getMessageList().append(message);
-
         xclick = 0;
         yclick = 0;
-
-        FloatingTextWidget *ft = message->floatingTextWidget();
-        //TODO cancel doesn't cancel the creation of the message, only cancels setting an operation.
-        //Shouldn't it cancel also the whole creation?
-        ft->showOperationDialog();
-        message->setTextPosition();
-        m_pUMLScene->getWidgetList().append(ft);
-
-        UMLApp::app()->document()->setModified();
     }
     else {
-        m_messageLine = new UMLSceneLineItem(m_pUMLScene->canvas());
+        m_messageLine = new UMLSceneLineItem();
+        m_messageLine->setCanvas(m_pUMLScene->canvas());
         m_messageLine->setPoints(m_pMouseEvent->x(), m_pMouseEvent->y(), m_pMouseEvent->x(), m_pMouseEvent->y());
         m_messageLine->setPen(QPen(m_pUMLScene->lineColor(), m_pUMLScene->lineWidth(), Qt::DashLine));
 
         m_messageLine->setVisible(true);
 
-        m_pUMLScene->viewport()->setMouseTracking(true);
+        m_pUMLScene->view()->viewport()->setMouseTracking(true);
     }
 }
 
@@ -281,19 +265,8 @@ void ToolBarStateMessages::setSecondWidget(ObjectWidget* secondObject, MessageTy
 
     MessageWidget* message = new MessageWidget(m_pUMLScene, m_firstObject,
                                                secondObject, y, msgType);
-
+    setupMessageWidget(message);
     cleanMessage();
-
-    m_pUMLScene->getMessageList().append(message);
-
-    FloatingTextWidget *ft = message->floatingTextWidget();
-    //TODO cancel doesn't cancel the creation of the message, only cancels setting an operation.
-    //Shouldn't it cancel also the whole creation?
-    ft->showOperationDialog();
-    message->setTextPosition();
-    m_pUMLScene->getWidgetList().append(ft);
-
-    UMLApp::app()->document()->setModified();
 }
 
 /**
@@ -327,4 +300,20 @@ void ToolBarStateMessages::cleanMessage()
     m_messageLine = 0;
 }
 
+void ToolBarStateMessages::setupMessageWidget(MessageWidget *message)
+{
+    m_pUMLScene->messageList().append(message);
+    m_pUMLScene->addItem(message);
+    message->activate();
+
+    FloatingTextWidget *ft = message->floatingTextWidget();
+    //TODO cancel doesn't cancel the creation of the message, only cancels setting an operation.
+    //Shouldn't it cancel also the whole creation?
+    ft->showOperationDialog();
+    message->setTextPosition();
+    m_pUMLScene->widgetList().append(ft);
+
+    UMLApp::app()->document()->setModified();
+}
+
 #include "toolbarstatemessages.moc"
