@@ -13,6 +13,7 @@
 
 // application specific includes
 #include "debug_utils.h"
+#include "dotgenerator.h"
 #include "model_utils.h"
 #include "uml.h"
 #include "umldoc.h"
@@ -61,6 +62,8 @@ QStringList UMLViewImageExporterModel::supportedImageTypes()
                 s_supportedImageTypesList << format;
         }
         // specific supported formats
+        if (!s_supportedImageTypesList.contains("dot"))
+            s_supportedImageTypesList << "dot";
         if (!s_supportedImageTypesList.contains("eps"))
             s_supportedImageTypesList << "eps";
         if (!s_supportedImageTypesList.contains("svg"))
@@ -103,6 +106,7 @@ QString UMLViewImageExporterModel::imageTypeToMimeType(const QString& imageType)
 {
     const QString imgType = imageType.toLower();
     if (QString("bmp") == imgType) return "image/bmp";
+    if (QString("dot") == imgType) return "image/x-dot";
     if (QString("jpeg") == imgType) return "image/jpeg";
     if (QString("pbm") == imgType) return "image/x-portable-bitmap";
     if (QString("pgm") == imgType) return "image/x-portable-graymap";
@@ -126,6 +130,7 @@ QString UMLViewImageExporterModel::imageTypeToMimeType(const QString& imageType)
 QString UMLViewImageExporterModel::mimeTypeToImageType(const QString& mimeType)
 {
     if (QString("image/bmp") == mimeType) return "bmp";
+    if (QString("image/x-dot") == mimeType) return "dot";
     if (QString("image/jpeg") == mimeType) return "jpeg";
     if (QString("image/x-portable-bitmap") == mimeType) return "pbm";
     if (QString("image/x-portable-graymap") == mimeType) return "pgm";
@@ -267,7 +272,7 @@ QString UMLViewImageExporterModel::getDiagramFileName(UMLScene* scene, const QSt
     if (scene) {
         if (useFolders) {
             qApp->processEvents();  //:TODO: still needed ???
-            return Model_Utils::treeViewBuildDiagramName(scene->getID());
+            return Model_Utils::treeViewBuildDiagramName(scene->ID());
         }
         else {
             return scene->name() + '.' + imageType.toLower();;
@@ -329,7 +334,11 @@ bool UMLViewImageExporterModel::exportViewTo(UMLScene* scene, const QString &ima
     scene->clearSelected();
 
     QString imageMimeType = UMLViewImageExporterModel::imageTypeToMimeType(imageType);
-    if (imageMimeType == "image/x-eps") {
+    if (imageMimeType == "image/x-dot") {
+        if (!exportViewToDot(scene, fileName)) {
+            return false;
+        }
+    } else if (imageMimeType == "image/x-eps") {
         if (!exportViewToEps(scene, fileName, true)) {
             return false;
         }
@@ -346,6 +355,28 @@ bool UMLViewImageExporterModel::exportViewTo(UMLScene* scene, const QString &ima
     return true;
 }
 
+/**
+ * Exports the view to the file 'fileName' as a dot file.
+ *
+ * @param scene     The scene to export.
+ * @param fileName  The name of the file where the image will be saved.
+ * @return True if the operation was successful,
+ *         false if a problem occurred while exporting.
+ */
+bool UMLViewImageExporterModel::exportViewToDot(UMLScene* scene, const QString &fileName) const
+{
+    if (!scene) {
+        uWarning() << "Scene is null!";
+        return false;
+    }
+
+    DotGenerator dot;
+    bool result = dot.createDotFile(scene, fileName, QLatin1String("export"));
+
+    DEBUG(DBG_IEM) << "saving to file " << fileName << result;
+    return result;
+}
+
 /**
  * Exports the view to the file 'fileName' as EPS.
  *
@@ -392,7 +423,7 @@ bool UMLViewImageExporterModel::exportViewToEps(UMLScene* scene, const QString &
     // and the actual painting
     scene->forceUpdateWidgetFontMetrics(painter);
 
-    QRect rect = scene->diagramRect();
+    UMLSceneRect rect = scene->diagramRect();
     painter->translate(-rect.x(), -rect.y());
     scene->getDiagram(rect, *painter);
 
@@ -413,59 +444,6 @@ bool UMLViewImageExporterModel::exportViewToEps(UMLScene* scene, const QString &
     return exportSuccessful;
 }
 
-/**
- * Fix the file 'fileName' to be a valid EPS containing the
- * specified area (rect) of the diagram.
- * Corrects the bounding box.
- *
- * @return True if the operation was successful,
- *         false if a problem occurred while exporting.
- */
-bool UMLViewImageExporterModel::fixEPS(const QString &fileName, const QRect& rect) const
-{
-    // now open the file and make a correct eps out of it
-    QFile epsfile(fileName);
-    if (! epsfile.open(QIODevice::ReadOnly)) {
-        return false;
-    }
-    // read
-    QTextStream ts(&epsfile);
-    QString fileContent = ts.readAll();
-    epsfile.close();
-
-    // read information
-    QRegExp rx("%%BoundingBox:\\s*(-?[\\d\\.:]+)\\s*(-?[\\d\\.:]+)\\s*(-?[\\d\\.:]+)\\s*(-?[\\d\\.:]+)");
-    const int pos = rx.indexIn(fileContent);
-    if (pos < 0) {
-        uError() << fileName << ": cannot find %%BoundingBox";
-        return false;
-    }
-
-    // write new content to file
-    if (! epsfile.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
-        uError() << fileName << ": cannot open file for writing";
-        return false;
-    }
-
-    // be careful when rounding (ceil/floor) the BB, these roundings
-    // were mainly obtained experimentally...
-    const double epsleft = rx.cap(1).toFloat();
-    const double epstop = rx.cap(4).toFloat();
-    const int left = int(floor(epsleft));
-    const int right = int(ceil(epsleft)) + rect.width();
-    const int top = int(ceil(epstop)) + 1;
-    const int bottom = int(floor(epstop)) - rect.height() + 1;
-
-    // modify content
-    fileContent.replace(pos,rx.cap(0).length(),
-                        QString("%%BoundingBox: %1 %2 %3 %4").arg(left).arg(bottom).arg(right).arg(top));
-
-    ts << fileContent;
-    epsfile.close();
-
-    return true;
-}
-
 /**
  * Exports the view to the file 'fileName' as SVG.
  *
@@ -482,7 +460,7 @@ bool UMLViewImageExporterModel::exportViewToSvg(UMLScene* scene, const QString &
     }
 
     bool exportSuccessful;
-    QRect rect = scene->diagramRect();
+    UMLSceneRect rect = scene->diagramRect();
 
     QSvgGenerator generator;
     generator.setFileName(fileName);
@@ -530,12 +508,67 @@ bool UMLViewImageExporterModel::exportViewToPixmap(UMLScene* scene, const QStrin
         return false;
     }
 
-    bool exportSuccessful;
-    QRect rect = scene->diagramRect();
+    UMLSceneRect rect = scene->diagramRect();
     QPixmap diagram(rect.width(), rect.height());
     scene->getDiagram(rect, diagram);
-    exportSuccessful = diagram.save(fileName, qPrintable(imageType.toUpper()));
-
-    DEBUG(DBG_IEM) << "saving to file " << fileName << " , imageType=" << imageType << " successful=" << exportSuccessful;
+    bool exportSuccessful = diagram.save(fileName, qPrintable(imageType.toUpper()));
+    DEBUG(DBG_IEM) << "saving to file " << fileName
+                   << " , imageType=" << imageType
+                   << " , width=" << rect.width()
+                   << " , height=" << rect.height()
+                   << " , successful=" << exportSuccessful;
     return exportSuccessful;
 }
+
+/**
+ * Fix the file 'fileName' to be a valid EPS containing the
+ * specified area (rect) of the diagram.
+ * Corrects the bounding box.
+ *
+ * @return True if the operation was successful,
+ *         false if a problem occurred while exporting.
+ */
+bool UMLViewImageExporterModel::fixEPS(const QString &fileName, const UMLSceneRect& rect) const
+{
+    // now open the file and make a correct eps out of it
+    QFile epsfile(fileName);
+    if (! epsfile.open(QIODevice::ReadOnly)) {
+        return false;
+    }
+    // read
+    QTextStream ts(&epsfile);
+    QString fileContent = ts.readAll();
+    epsfile.close();
+    
+    // read information
+    QRegExp rx("%%BoundingBox:\\s*(-?[\\d\\.:]+)\\s*(-?[\\d\\.:]+)\\s*(-?[\\d\\.:]+)\\s*(-?[\\d\\.:]+)");
+    const int pos = rx.indexIn(fileContent);
+    if (pos < 0) {
+        uError() << fileName << ": cannot find %%BoundingBox";
+        return false;
+    }
+    
+    // write new content to file
+    if (! epsfile.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
+        uError() << fileName << ": cannot open file for writing";
+        return false;
+    }
+    
+    // be careful when rounding (ceil/floor) the BB, these roundings
+    // were mainly obtained experimentally...
+    const double epsleft = rx.cap(1).toFloat();
+    const double epstop = rx.cap(4).toFloat();
+    const int left = int(floor(epsleft));
+    const int right = int(ceil(epsleft)) + rect.width();
+    const int top = int(ceil(epstop)) + 1;
+    const int bottom = int(floor(epstop)) - rect.height() + 1;
+    
+    // modify content
+    fileContent.replace(pos,rx.cap(0).length(),
+                        QString("%%BoundingBox: %1 %2 %3 %4").arg(left).arg(bottom).arg(right).arg(top));
+    
+    ts << fileContent;
+    epsfile.close();
+    
+    return true;
+}
