@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2011                                               *
+ *   copyright (C) 2002-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -28,12 +28,22 @@
 #include "listpopupmenu.h"
 #include "dialog_utils.h"
 
+/**
+ * Creates a Combined Fragment widget.
+ *
+ * @param scene              The parent of the widget.
+ * @param combinedfragmentType      The type of combined fragment.
+ * @param id                The ID to assign (-1 will prompt a new ID.)
+ */
 CombinedFragmentWidget::CombinedFragmentWidget(UMLScene * scene, CombinedFragmentType combinedfragmentType, Uml::IDType id )
   : UMLWidget(scene, WidgetBase::wt_CombinedFragment, id)
 {
     setCombinedFragmentType( combinedfragmentType );
 }
 
+/**
+ *  Destructor.
+ */
 CombinedFragmentWidget::~CombinedFragmentWidget()
 {
     for(QList<FloatingDashLineWidget*>::iterator it=m_dashLines.begin() ; it!=m_dashLines.end() ; ++it) {
@@ -41,6 +51,9 @@ CombinedFragmentWidget::~CombinedFragmentWidget()
     }
 }
 
+/**
+ * Overrides the standard paint event.
+ */
 void CombinedFragmentWidget::paint(QPainter & p, int offsetX, int offsetY)
 {
     int w = width();
@@ -61,7 +74,7 @@ void CombinedFragmentWidget::paint(QPainter & p, int offsetX, int offsetY)
     int textStartY = (h / 2) - (fontHeight / 2);
     p.drawRect(offsetX, offsetY, w, h );
 
-    p.setPen(Qt::black);
+    p.setPen(textColor());
     p.setFont( UMLWidget::font() );
         QString temp = "loop";
 
@@ -113,19 +126,19 @@ void CombinedFragmentWidget::paint(QPainter & p, int offsetX, int offsetY)
                 {
                      temp = '[' + combined_fragment_value + ']';
             p.drawText(offsetX + COMBINED_FRAGMENT_MARGIN, offsetY + 20,w - COMBINED_FRAGMENT_MARGIN * 2, fontHeight, Qt::AlignLeft, temp);
-                    if (m_dashLines.size() == 1 && m_dashLines.first()->getY() < offsetY + 20 + fontHeight )
+                    if (m_dashLines.size() == 1 && m_dashLines.first()->y() < offsetY + 20 + fontHeight )
                         m_dashLines.first()->setY(offsetY + h/2);
                 }
                 p.drawText(offsetX + COMBINED_FRAGMENT_MARGIN, offsetY ,
             w - COMBINED_FRAGMENT_MARGIN * 2, fontHeight, Qt::AlignLeft, "alt");
                 // dash lines
-                m_dashLines.first()->paint(p,getX(),getY());
+                m_dashLines.first()->paint(p,x(),y());
                 for(QList<FloatingDashLineWidget*>::iterator it=m_dashLines.begin() ; it!=m_dashLines.end() ; ++it) {
-                    (*it)->setX(getX());
+                    (*it)->setX(x());
                     old_Y = (*it)->getYMin();
-                    (*it)->setYMin(getY());
-                    (*it)->setYMax(getY() + getHeight());
-                    (*it)->setY(getY() + (*it)->getY() - old_Y);
+                    (*it)->setYMin(y());
+                    (*it)->setYMax(y() + height());
+                    (*it)->setY(y() + (*it)->y() - old_Y);
                     (*it)->setSize(w, 0);
                 }
 
@@ -136,13 +149,13 @@ void CombinedFragmentWidget::paint(QPainter & p, int offsetX, int offsetY)
             w - COMBINED_FRAGMENT_MARGIN * 2, fontHeight, Qt::AlignLeft, "parallel");
                 // dash lines
                 if (m_dashLines.size() != 0) {
-                    m_dashLines.first()->paint(p,getX(),getY());
+                    m_dashLines.first()->paint(p,x(),y());
                     for(QList<FloatingDashLineWidget*>::iterator it=m_dashLines.begin() ; it!=m_dashLines.end() ; ++it) {
-                        (*it)->setX(getX());
+                        (*it)->setX(x());
                         old_Y = (*it)->getYMin();
-                        (*it)->setYMin(getY());
-                        (*it)->setYMax(getY() + getHeight());
-                        (*it)->setY(getY() + (*it)->getY() - old_Y);
+                        (*it)->setYMin(y());
+                        (*it)->setYMax(y() + height());
+                        (*it)->setY(y() + (*it)->y() - old_Y);
                         (*it)->setSize(w, 0);
                     }
                 }
@@ -160,6 +173,9 @@ void CombinedFragmentWidget::paint(QPainter & p, int offsetX, int offsetY)
         drawSelected(&p, offsetX, offsetY);
 }
 
+/**
+ * Overrides method from UMLWidget.
+ */
 UMLSceneSize CombinedFragmentWidget::minimumSize()
 {
     int width = 10, height = 10;
@@ -179,11 +195,17 @@ UMLSceneSize CombinedFragmentWidget::minimumSize()
     return UMLSceneSize(width, height);
 }
 
+/**
+ * Returns the type of combined fragment.
+ */
 CombinedFragmentWidget::CombinedFragmentType CombinedFragmentWidget::combinedFragmentType() const
 {
     return m_CombinedFragment;
 }
 
+/**
+ * Sets the type of combined fragment.
+ */
 void CombinedFragmentWidget::setCombinedFragmentType( CombinedFragmentType combinedfragmentType )
 {
     m_CombinedFragment = combinedfragmentType;
@@ -196,15 +218,18 @@ void CombinedFragmentWidget::setCombinedFragmentType( CombinedFragmentType combi
         {
             m_dashLines.back()->setText("else");
         }
-        m_dashLines.back()->setX(getX());
-        m_dashLines.back()->setYMin(getY());
-        m_dashLines.back()->setYMax(getY() + getHeight());
-        m_dashLines.back()->setY(getY() + height()/2);
-        m_dashLines.back()->setSize(getWidth(), 0);
+        m_dashLines.back()->setX(x());
+        m_dashLines.back()->setYMin(y());
+        m_dashLines.back()->setYMax(y() + height());
+        m_dashLines.back()->setY(y() + height()/2);
+        m_dashLines.back()->setSize(width(), 0);
         m_scene->setupNewWidget(m_dashLines.back());
     }
 }
 
+/**
+ * Returns the type of combined fragment.
+ */
 CombinedFragmentWidget::CombinedFragmentType CombinedFragmentWidget::combinedFragmentType(const QString& type) const
 {
     if(type == "Reference")
@@ -230,11 +255,17 @@ CombinedFragmentWidget::CombinedFragmentType CombinedFragmentWidget::combinedFra
     return (CombinedFragmentWidget::Ref);
 }
 
+/**
+ * Sets the type of combined fragment.
+ */
 void CombinedFragmentWidget::setCombinedFragmentType( const QString& combinedfragmentType )
 {
     setCombinedFragmentType(combinedFragmentType(combinedfragmentType) );
 }
 
+/**
+ * ...
+ */
 void CombinedFragmentWidget::askNameForWidgetType(UMLWidget* &targetWidget, const QString& dialogTitle,
     const QString& dialogPrompt, const QString& defaultName)
 {
@@ -260,6 +291,9 @@ void CombinedFragmentWidget::askNameForWidgetType(UMLWidget* &targetWidget, cons
     }
 }
 
+/**
+ * Saves the widget to the "combinedFragmentwidget" XMI element.
+ */
 void CombinedFragmentWidget::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
 {
     QDomElement combinedFragmentElement = qDoc.createElement( "combinedFragmentwidget" );
@@ -276,6 +310,9 @@ void CombinedFragmentWidget::saveToXMI( QDomDocument & qDoc, QDomElement & qElem
     qElement.appendChild( combinedFragmentElement );
 }
 
+/**
+ * Loads the widget from the "CombinedFragmentwidget" XMI element.
+ */
 bool CombinedFragmentWidget::loadFromXMI( QDomElement & qElement )
 {
     if( !UMLWidget::loadFromXMI( qElement ) )
@@ -314,6 +351,11 @@ bool CombinedFragmentWidget::loadFromXMI( QDomElement & qElement )
     return true;
 }
 
+/**
+ * Overrides the function from UMLWidget.
+ *
+ * @param action  The command to be executed.
+ */
 void CombinedFragmentWidget::slotMenuSelection(QAction* action)
 {
     bool ok = false;
@@ -327,11 +369,11 @@ void CombinedFragmentWidget::slotMenuSelection(QAction* action)
         {
             m_dashLines.back()->setText("else");
         }
-        m_dashLines.back()->setX(getX());
-        m_dashLines.back()->setYMin(getY());
-        m_dashLines.back()->setYMax(getY() + getHeight());
-        m_dashLines.back()->setY(getY() + getHeight() / 2);
-        m_dashLines.back()->setSize(getWidth(), 0);
+        m_dashLines.back()->setX(x());
+        m_dashLines.back()->setYMin(y());
+        m_dashLines.back()->setYMax(y() + height());
+        m_dashLines.back()->setY(y() + height() / 2);
+        m_dashLines.back()->setSize(width(), 0);
         m_scene->setupNewWidget(m_dashLines.back());
         break;
 
@@ -355,4 +397,3 @@ void CombinedFragmentWidget::slotMenuSelection(QAction* action)
 }
 
 #include "combinedfragmentwidget.moc"
-
