@@ -13,9 +13,9 @@
 
 #include <QtGui/QPainter>
 #include <QtCore/QStringList>
+#include <QMetaEnum>
 
 #include "umlwidget.h"
-#include "worktoolbar.h"
 
 #define STATE_MARGIN 5
 #define STATE_WIDTH 30
@@ -63,10 +63,8 @@ public:
 
     void paint(QPainter & p, int offsetX, int offsetY);
 
-    virtual QString name() const;
-    virtual void setName(const QString &strName);
-
     StateType stateType() const;
+    QString stateTypeStr() const;
     void setStateType(StateType stateType);
 
     bool addActivity(const QString &activity);
@@ -76,22 +74,25 @@ public:
     QStringList activities() const;
     void setActivities(const QStringList &list);
 
-    virtual void showPropertiesDialog();
+    bool drawVertical() const;
+    void setDrawVertical(bool to = true);
 
-    static bool isState(WorkToolBar::ToolBar_Buttons tbb,
-                        StateType& resultType);
+    virtual void showPropertiesDialog();
 
     virtual bool loadFromXMI(QDomElement & qElement);
     virtual void saveToXMI(QDomDocument & qDoc, QDomElement & qElement);
 
 protected:
     UMLSceneSize minimumSize();
+    UMLSceneSize maximumSize();
+    void setAspectRatioMode();
 
 public slots:
     virtual void slotMenuSelection(QAction* action);
 
 private:
     StateType   m_stateType;   ///< Type of state.
+    bool m_drawVertical;   ///< whether to draw the fork/join horizontally or vertically
     QStringList m_Activities;  ///< List of activities for the state.
 
 };
