@@ -24,28 +24,24 @@
  */
 WidgetBase::WidgetBase(UMLScene *scene, WidgetType type)
   : QObject(scene),
-    m_Type(type),
-    m_scene(scene)
+    m_baseType(type),
+    m_scene(scene),
+    m_pObject(0)
 {
-    init();
-}
-
-/**
- * Initialize members.
- */
-void WidgetBase::init()
-{
-    m_pObject = 0;
     if (m_scene) {
         m_usesDiagramLineColor = true;
         m_usesDiagramLineWidth  = true;
+        m_usesDiagramTextColor = true;
         const Settings::OptionState& optionState = m_scene->optionState();
+        m_textColor = optionState.uiState.textColor;
         m_LineColor = optionState.uiState.lineColor;
         m_LineWidth  = optionState.uiState.lineWidth;
     } else {
         uError() << "WidgetBase constructor: SERIOUS PROBLEM - m_scene is NULL";
         m_usesDiagramLineColor = false;
         m_usesDiagramLineWidth  = false;
+        m_usesDiagramTextColor = false;
+        m_textColor =  QColor("black");
         m_LineColor = QColor("black");
         m_LineWidth = 0; // initialize with 0 to have valid start condition
     }
@@ -59,19 +55,11 @@ WidgetBase::~WidgetBase()
 }
 
 /**
- * Set property m_Type.
- */
-void WidgetBase::setBaseType(WidgetBase::WidgetType type)
-{
-    m_Type = type;
-}
-
-/**
- * Read property of m_Type.
+ * Read property of m_baseType.
  */
 WidgetBase::WidgetType WidgetBase::baseType() const
 {
-    return m_Type;
+    return m_baseType;
 }
 
 /**
@@ -79,7 +67,7 @@ WidgetBase::WidgetType WidgetBase::baseType() const
  */
 QLatin1String WidgetBase::baseTypeStr() const
 {
-    return QLatin1String(ENUM_NAME(WidgetBase, WidgetType, m_Type));
+    return QLatin1String(ENUM_NAME(WidgetBase, WidgetType, m_baseType));
 }
 
 /**
@@ -116,9 +104,9 @@ UMLObject* WidgetBase::umlObject() const
  *
  * @param o The object to represent.
  */
-void WidgetBase::setUMLObject(UMLObject * o)
+void WidgetBase::setUMLObject(UMLObject *obj)
 {
-    m_pObject = o;
+    m_pObject = obj;
 }
 
 /**
@@ -171,6 +159,27 @@ void WidgetBase::setDocumentation( const QString &doc )
         m_Doc = doc;
 }
 
+/**
+ * Returns text color
+ *
+ * @return currently used text color
+ */
+QColor WidgetBase::textColor() const
+{
+    return m_textColor;
+}
+
+/**
+ * Sets the text color
+ *
+ * @param color the new text color
+ */
+void WidgetBase::setTextColor(const QColor &color)
+{
+    m_textColor = color;
+    m_usesDiagramTextColor = false;
+}
+
 /**
  * Returns line color
  *
@@ -255,6 +264,30 @@ void WidgetBase::setUseFillColor(bool state)
     m_usesDiagramUseFillColor = false;
 }
 
+/**
+ * Returns state if diagram text color is used
+ *
+ * @return True means diagram text color is used
+ */
+bool WidgetBase::usesDiagramTextColor() const
+{
+    return m_usesDiagramTextColor;
+}
+
+/**
+ * Set state if diagram text color is used
+ *
+ * @param state  The state to set
+ */
+void WidgetBase::setUsesDiagramTextColor(bool state)
+{
+    if (m_usesDiagramTextColor == state) {
+        return;
+    }
+    m_usesDiagramTextColor = state;
+    setTextColor(m_textColor);
+}
+
 /**
  * Returns state of diagram line color is used
  *
@@ -337,6 +370,8 @@ void WidgetBase::setUsesDiagramLineWidth(bool state)
 
 void WidgetBase::saveToXMI( QDomDocument & /*qDoc*/, QDomElement & qElement )
 {
+    qElement.setAttribute( "textcolor", m_usesDiagramTextColor ? "none" : m_textColor.name() );
+
     if (m_usesDiagramLineColor) {
         qElement.setAttribute( "linecolor", "none" );
     } else {
@@ -368,7 +403,7 @@ bool WidgetBase::loadFromXMI( QDomElement & qElement )
     if (lineColor != "none") {
         setLineColor( QColor(lineColor) );
         m_usesDiagramLineColor = false;
-    } else if (m_Type != WidgetBase::wt_Box && m_scene != NULL) {
+    } else if (m_baseType != WidgetBase::wt_Box && m_scene != NULL) {
         setLineColor( m_scene->lineColor() );
         m_usesDiagramLineColor = true;
     }
@@ -380,6 +415,14 @@ bool WidgetBase::loadFromXMI( QDomElement & qElement )
         setLineWidth( m_scene->lineWidth() );
         m_usesDiagramLineWidth = true;
     }
+    QString textColor = qElement.attribute( "textcolor", "none" );
+    if (textColor != "none") {
+        setTextColor( QColor(textColor) );
+        m_usesDiagramTextColor = false;
+    } else if ( m_scene ) {
+        setTextColor( m_scene->textColor() );
+        m_usesDiagramTextColor = true;
+    }
     QString usefillcolor = qElement.attribute("usefillcolor", "1");
     m_useFillColor = (bool)usefillcolor.toInt();
     /*
@@ -409,7 +452,7 @@ bool WidgetBase::loadFromXMI( QDomElement & qElement )
  */
 WidgetBase& WidgetBase::operator=(const WidgetBase& other)
 {
-    m_Type = other.m_Type;
+    m_baseType = other.m_baseType;
     m_scene = other.m_scene;
     m_pObject = other.m_pObject;
     m_Doc = other.m_Doc;
