@@ -145,12 +145,12 @@ void WorkToolBar::slotCheckToolBar(Uml::DiagramType dt)
         insertHotBtn(tbb_State);
         insertHotBtn(tbb_End_State);
         insertHotBtn(tbb_State_Transition);
-        //insertHotBtn(tbb_DeepHistory);        //NotYetImplemented
-        //insertHotBtn(tbb_ShallowHistory);     //NotYetImplemented
-        //insertHotBtn(tbb_Join);               //NotYetImplemented
+        insertHotBtn(tbb_DeepHistory);
+        insertHotBtn(tbb_ShallowHistory);
+        insertHotBtn(tbb_StateJoin);
         insertHotBtn(tbb_StateFork);
-        //insertHotBtn(tbb_Junction);           //NotYetImplemented
-        //insertHotBtn(tbb_Choice);             //NotYetImplemented
+        insertHotBtn(tbb_Junction);
+        insertHotBtn(tbb_Choice);
         //insertHotBtn(tbb_Andline);            //NotYetImplemented
         break;
 
@@ -335,14 +335,14 @@ void WorkToolBar::loadPixmaps()
         { tbb_Datatype,                 i18n("Datatype"),                Icon_Utils::it_Datatype,                SLOT(slotDatatype()) },
         { tbb_Enum,                     i18n("Enum"),                    Icon_Utils::it_Enum,                    SLOT(slotEnum()) },
         { tbb_Entity,                   i18n("Entity"),                  Icon_Utils::it_Entity,                  SLOT(slotEntity()) },
-        { tbb_DeepHistory,              i18n("Deep History"),            Icon_Utils::it_History_Deep,            SLOT(slotDeepHistory()) },     //NotYetImplemented
-        { tbb_ShallowHistory,           i18n("Shallow History"),         Icon_Utils::it_History_Shallow,         SLOT(slotShallowHistory()) },  //NotYetImplemented
-        { tbb_StateJoin,                i18nc("join states", "Join"),    Icon_Utils::it_Join,                    SLOT(slotStateJoin()) },       //NotYetImplemented
+        { tbb_DeepHistory,              i18n("Deep History"),            Icon_Utils::it_History_Deep,            SLOT(slotDeepHistory()) },
+        { tbb_ShallowHistory,           i18n("Shallow History"),         Icon_Utils::it_History_Shallow,         SLOT(slotShallowHistory()) },
+        { tbb_StateJoin,                i18nc("join states", "Join"),    Icon_Utils::it_Join,                    SLOT(slotStateJoin()) },
         { tbb_StateFork,                i18n("Fork"),                    Icon_Utils::it_Fork_State,              SLOT(slotStateFork()) },
-        { tbb_Junction,                 i18n("Junction"),                Icon_Utils::it_Junction,                SLOT(slotJunction()) },        //NotYetImplemented
-        { tbb_Choice,                   i18nc("state choice", "Choice"), Icon_Utils::it_Choice_Round,            SLOT(slotChoice()) },          //NotYetImplemented
+        { tbb_Junction,                 i18n("Junction"),                Icon_Utils::it_Junction,                SLOT(slotJunction()) },
+        { tbb_Choice,                   i18nc("state choice", "Choice"), Icon_Utils::it_Choice_Rhomb,            SLOT(slotChoice()) },
         //:TODO: let the user decide which symbol he wants (setting an option)
-        //    { tbb_Choice,                   i18n("Choice"),                  Icon_Utils::it_Choice_Rhomb,           SLOT(slotChoice()) },          //NotYetImplemented
+        //{ tbb_Choice,                   i18n("Choice"),                  Icon_Utils::it_Choice_Round,            SLOT(slotChoice()) },          //NotYetImplemented
         { tbb_Andline,                  i18n("And Line"),                Icon_Utils::it_And_Line,                SLOT(slotAndline()) },         //NotYetImplemented
         { tbb_State_Transition,         i18n("State Transition"),        Icon_Utils::it_State_Transition,        SLOT(slotState_Transition()) },
         { tbb_Activity_Transition,      i18n("Activity Transition"),     Icon_Utils::it_Activity_Transition,     SLOT(slotActivity_Transition()) },
